import React, { Component } from 'react';
import { TouchableNativeFeedback, TouchableOpacity, Platform, View } from 'react-native';
import PropTypes from 'prop-types';

export default class Button extends Component {
  static propTypes = {
    children: PropTypes.oneOfType([
      PropTypes.element,
      PropTypes.array
    ]),
    onPress: PropTypes.func,
    debounce: PropTypes.number
  };

  static defaultProps = {
    children: <View />,
    onPress: () => {},
    debounce: 1000
  };

  isTouchablePressed = false;

  onPressTouchable = () => {
    if (this.isTouchablePressed) {
      return;
    }

    this.isTouchablePressed = true;

    setTimeout(() => {
      this.isTouchablePressed = false;
    }, this.props.debounce);

    this.props.onPress();
  };

  render() {
    if (Platform.OS == 'android') {
      return (
        <TouchableNativeFeedback onPress={this.onPressTouchable}>
          { this.props.children }
        </TouchableNativeFeedback>
      );
    }
    else if (Platform.OS == 'ios') {
      return (
        <TouchableOpacity onPress={this.onPressTouchable}>
          { this.props.children }
        </TouchableOpacity>
      );
    }
  }
}
